# -*- coding: utf-8 -*-

# collection_update_response.py

"""
This script is automatically generated for TaskingAI python client
Do not modify the file manually

Author: James Yao
Organization: TaskingAI
License: Apache 2.0
"""

from pydantic import BaseModel, Field
from ..entities.collection import Collection

__all__ = ["CollectionUpdateResponse"]


class CollectionUpdateResponse(BaseModel):
    status: str = Field("success")
    data: Collection = Field(...)



# -*- coding: utf-8 -*-

# record_list_response.py

"""
This script is automatically generated for TaskingAI python client
Do not modify the file manually

Author: James Yao
Organization: TaskingAI
License: Apache 2.0
"""

from pydantic import BaseModel, Field
from typing import List
from ..entities.record import Record

__all__ = ["RecordListResponse"]


class RecordListResponse(BaseModel):
    status: str = Field("success")
    data: List[Record] = Field(...)
    fetched_count: int = Field(...)
    has_more: bool = Field(...)



# -*- coding: utf-8 -*-

# message_update_response.py

"""
This script is automatically generated for TaskingAI python client
Do not modify the file manually

Author: James Yao
Organization: TaskingAI
License: Apache 2.0
"""

from pydantic import BaseModel, Field
from ..entities.message import Message

__all__ = ["MessageUpdateResponse"]


class MessageUpdateResponse(BaseModel):
    status: str = Field("success")
    data: Message = Field(...)
